#!/usr/bin/env bash

## Source scripts
vendor_brewpixel_barista_bin_composer_dir=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

source "${vendor_brewpixel_barista_bin_composer_dir}/../../Burr/burr-dependencies.sh"
ensure_readlink_installed

if [[ "$OSTYPE" == "linux-gnu" ]]; then
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_composer_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
elif [[ "$OSTYPE" == "darwin"* ]]; then
	# Mac OSX
	vendor_brewpixel_barista_bin_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_composer_dir}"))
	vendor_brewpixel_barista_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(greadlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(greadlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(greadlink -f $(dirname "${vendor_dir}"))
	#project_base=$(greadlink -f $(dirname "${vendor_dir}"))
else
    # Unknown.
    vendor_brewpixel_barista_bin_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_composer_dir}"))
	vendor_brewpixel_barista_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_bin_dir}"))
	vendor_brewpixel_dir=$(readlink -f $(dirname "${vendor_brewpixel_barista_dir}"))
	vendor_dir=$(readlink -f $(dirname "${vendor_brewpixel_dir}"))
	project_base=$(readlink -f $(dirname "${vendor_dir}"))
	#project_base=$(readlink -f $(dirname "${scripts_dir}"))
fi

source "${vendor_brewpixel_barista_dir}/config.sh"
source "${vendor_brewpixel_barista_dir}/Burr/bootstrap.sh"
#source "${vendor_brewpixel_barista_dir}/../bashful/bin/bashful"

for f in $(ls "${vendor_brewpixel_barista_dir}/Burr/");
    do source "${vendor_brewpixel_barista_dir}/Burr/${f}";
done

## Install dependencies
ensure_jq_installed

# Include the local config variables which can override the default variables
if [ -f "${project_base}/config/env/local/localdev.cfg" ]; then
    source "${project_base}/config/env/local/localdev.cfg"
else
    echo "2. No local config file found at ${project_base}/config/env/local/localdev.cfg"
fi

bitbucket_consumer_access_token="$(curl "${bitbucket_access_token_url}" \
    -d grant_type=client_credentials \
    -u ${bitbucket_consumer_key}:${bitbucket_consumer_secret} | jq '.access_token')"

## Create new remote repo at BitBucket
bitbucket_repo_exists "${main_repo_name}"
error=$(echo "${bitbucket_repo_already_exists}" | grep -c "error")

if [ ${error} -ne 0 ]; then
	bitbucket_create_project
	bitbucket_create_main_repo
	bitbucket_create_theme_repo
	bitbucket_create_mockups_repo
else
	echo "There was an error and a repo with the same name may already exist."
	echo "Trying www.${main_repo_name} instead"
	bitbucket_create_project
	bitbucket_create_main_repo_no_conflict
	bitbucket_create_theme_repo
	bitbucket_create_mockups_repo
fi

git_clone_repo "${project_base}" git@bitbucket.org:brewpixel/maker-template.git maker
cd "${project_base}/maker"
if [ -d .git ]; then
cd "${project_base}/maker" && rm -rf .git
fi

# @TODO: 
#"php -r \"copy('maker/maker-config-sample.php', 'maker/maker-config.php');\""
if [ ! -f "${project_base}/maker/maker-config.php" ]; then
    ownergroup="$(ls -ld "${project_base}/public_html/wp-config.php" | awk 'NR==1 {print $3":"$4}')"
    cp "${project_base}/maker/maker-config-sample.php" "${project_base}/maker/maker-config.php"
    chown ${ownergroup} "${project_base}/maker/maker-config.php"
fi

## Clone and install new roastery site
git_initialise_with_remote_repo "${project_base}" "${bitbucket_remote_url_main_repo}"

# Check for type of install to know which theme needs renamed
if [ -d "${project_base}/public_html/content/themes/moka-child-starter" ]; then
	cd "${project_base}/public_html/content/themes/moka-child-starter"
	if [ -d .git ]; then
		cd "${project_base}/public_html/content/themes/moka-child-starter" && rm -rf .git
	fi
	mv "${project_base}/public_html/content/themes/moka-child-starter" "${project_base}/public_html/content/themes/${theme_name_lowercase_hyphen_no_spaces}"
fi

if [ -d "${project_base}/public_html/content/themes/genesis-child-starter" ]; then
	cd "${project_base}/public_html/content/themes/genesis-child-starter"
	if [ -d .git ]; then
		cd "${project_base}/public_html/content/themes/genesis-child-starter" && rm -rf .git
	fi
	mv "${project_base}/public_html/content/themes/genesis-child-starter" "${project_base}/public_html/content/themes/${theme_name_lowercase_hyphen_no_spaces}"
fi


# Replace info in composer.json located in main repo with new theme name info.
#,
#    {
#      "type": "vcs",
#      "url": "git@bitbucket.org:brewpixel/redcarpet-child.git"
#    }
#"require": {
#    "brewpixel/redcarpet-child": "dev-master"
#  },

# Replace info in composer.json located in theme repo with new theme name info.
#"name": "brewpixel/redcarpet-child",

# Replace style.css theme info

if [ ! -d "${project_base}/public_html/content/themes/${theme_name_lowercase_hyphen_no_spaces}/.git" ]; then
	git_initialise_with_remote_repo "${project_base}/public_html/content/themes/${theme_name_lowercase_hyphen_no_spaces}" "${bitbucket_remote_url_theme_repo}"
fi

if [ ! -d "${project_base}/brewpixel-mockups/.git" ]; then
	git_initialise_with_remote_repo "${project_base}/brewpixel-mockups" "${bitbucket_remote_url_mockups_repo}"
fi
